#
# spec file for package neko
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           neko
Version:        2.2.0
Release:        bp153.1.18
Summary:        A cross-platform lightweight virtual machine and language
License:        MIT
Group:          Development/Languages/Other
Url:            https://nekovm.org
Source0:        https://github.com/HaxeFoundation/neko/archive/v2-2-0/neko-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  git
BuildRequires:  apache2-devel
BuildRequires:  gc-devel
BuildRequires:  gtk2-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  pcre-devel-static
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel-static
BuildRequires:  mbedtls-devel >= 2.2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       libneko2 = %{version}
Provides:       nekovm = %version
Obsoletes:      nekovm < %version

%description
Neko VM is a virtual machine for the Neko language. Neko is a
high-level dynamically typed programming language. It can be used as
an embedded scripting language.

%package devel
Summary:        Development files for the Neko virtual machine
License:        MIT
Group:          Development/Languages/Other
Requires:       libneko2 = %{version}
Provides:       nekovm-devel = %version
Obsoletes:      nekovm-devel < %version

%description devel
Development files and headers for the Neko virtual machine.

%package -n libneko2
Summary:        Neko virtual machine shared library
License:        MIT
Group:          System/Libraries

%description -n libneko2
Shared library for the Neko virtual machine.

%package mysql
Summary:        Neko virtual machine MySQL library
License:        GPL-2.0+
Group:          System/Libraries
Requires:       %{name} = %{version}
Provides:       nekovm-mysql = %version
Obsoletes:      nekovm-mysql < %version

%description mysql
MySQL library for the Neko virtual machine.

%prep
%setup -q -n neko-2-2-0

%build
%define __builder ninja

# modify CMAKE_C_FLAGS for strict-aliasing-punning
# https://github.com/HaxeFoundation/neko/issues/175
%cmake \
    -G Ninja \
    -DCMAKE_C_FLAGS:STRING="%optflags -fno-strict-aliasing" \
    -DWITH_APACHE=OFF \
    -DRELOCATABLERELOCATABLE=OFF \
    -DRUN_LDCONFIG=OFF
# make_jobs macro does not use ninja in openSUSE_13.2 / Leap_42.1
%make_jobs || %__builder -v %{?_smp_mflags}

%check

# ctest macro has not been defined in openSUSE_13.1
%{!?ctest: %define ctest ctest --output-on-failure --force-new-ctest-process %{?_smp_mflags}}
%ctest

%install
# cmake_install does not use ninja in openSUSE_13.2 / Leap_42.1
%cmake_install || DESTDIR=%{buildroot} %__builder install -C build

%post -n libneko2 -p /sbin/ldconfig

%postun -n libneko2 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%dir %{_libdir}/neko
%{_libdir}/neko/regexp.ndll
%{_libdir}/neko/sqlite.ndll
%{_libdir}/neko/std.ndll
%{_libdir}/neko/ui.ndll
%{_libdir}/neko/zlib.ndll
%{_libdir}/neko/ssl.ndll
%{_libdir}/neko/nekoml.std
%doc LICENSE CHANGES

%files mysql
%defattr(-,root,root)
%{_libdir}/neko/mysql.ndll
%{_libdir}/neko/mysql5.ndll
%doc LICENSE CHANGES

%files -n libneko2
%defattr(-,root,root)
%{_libdir}/*.so.*
%doc LICENSE CHANGES

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/cmake/*
%doc LICENSE CHANGES

%changelog
* Wed Dec 20 2017 andy@onthewings.net
- Update to neko 2.2.0.
  * Backward compatible to neko 2.1.0.
  * Improvements in CMake build options.
  * Minor fixes related to utf8, https, mysql and sqlite support.
  * Added `nekotools boot -c` to generate a C file for a .n file.
  * Full changelog can be viewed at:
    https://github.com/HaxeFoundation/neko/blob/master/CHANGES
- Remove patches already applied in 2.2.0:
  * patch0000-GC_INCLUDE_DIRS.diff
  * patch0001-INSTALL_DIR.diff
  * patch0002-GNUInstallDirs.diff
  * patch0003-NEKOMODULE_PATH.diff
  * patch0004-target_include_directories.patch
  * patch0005-mincoming-stack-boundary.patch
  * patch0006-INCLUDEDIR.diff
  * patch0007-CMAKE_INSTALL_LIBDIR.diff
  * nekovm-boot-c-1.patch
  * nekovm-boot-c-2.patch
  * nekovm-xlocale.patch
* Tue Sep  5 2017 andy@onthewings.net
- Add nekovm-xlocale.patch from upstream.
* Tue Jun 13 2017 jengelh@inai.de
- Ensure neutrality of description. Replace filler wording and
  by more concrete characteristics.
* Mon Jun  5 2017 andy@onthewings.net
- Add patches from upstream for creating strippable binaries.
  * nekovm-boot-c-1.patch
  * nekovm-boot-c-2.patch
- Make sure Ninja is used since there is problem building in
  parallel using Make.
* Sat Oct 29 2016 andy@onthewings.net
- Update to neko 2.1.0.
  * Remove patches already applied in 2.1.0:
  * 0001-library-paths.patch
  * 0002-ndll-paths.patch
  * 0003-no-apache.patch
  * 0004-no-mod_tora.patch
  * 0005-set-soname.patch
  * 0006-libmysqlclient.patch
  * 0007-extra-cflags.patch
  * 0008-jit.patch
  * Add upstream patches:
  * patch0000-GC_INCLUDE_DIRS.diff: fix a CMake variable typo.
  * patch0001-INSTALL_DIR.diff, patch0002-GNUInstallDirs.diff,
    and patch0003-NEKOMODULE_PATH.diff: fix install paths.
  * patch0004-target_include_directories.patch: fix CMake
    target_include_directories shim.
  * patch0005-mincoming-stack-boundary.patch: use
  - mincoming-stack-boundary when it is available.
  * patch0006-INCLUDEDIR.diff: add missing reference to
  * _INCLUDEDIR in CMake.
  * patch0007-CMAKE_INSTALL_LIBDIR.diff: make sure
    CMAKE_INSTALL_LIBDIR is relative.
* Fri Nov 27 2015 andy@onthewings.net
- Rename package from nekovm to neko.
* Thu Nov 26 2015 andy@onthewings.net
- License has been changed to MIT since neko 2.0.0.
- Include patch of the upstream fix on JIT.
- Provide .so.0 for compatibility with Debian.
- Put libneko1 and neko-mysql to System/Libraries group.
- Spec file clean up.
  * Added BuildRoot as suggested in openSUSE specfile guidelines.
- Remove nekoml.std from _bindir as it is not needed.
* Sat Jan 24 2015 prusnak@opensuse.org
- imported package from dmacvicar (version 2.0)
